@@ -1,4 +1,5 @@
-from typing import List, Tuple, TYPE_CHECKING, Optional, Callable, Awaitable
+from itertools import islice
+from typing import List, Tuple, TYPE_CHECKING, Optional, Callable, Awaitable, FrozenSet
 
 from twitchbot import get_bot
 from .util import get_message_mentions
@@ -35,6 +36,34 @@ class Message:
 
         self._parse()
 
+    def _normalize(self, s: str):
+        return s.strip().casefold()
+
+    @property
+    def normalized_parts(self) -> FrozenSet[str]:
+        """
+        parts of the message,
+        but they are are stripped of any leading or trailing whitespace
+        and converted to lowercase
+        """
+        return frozenset(map(self._normalize, self.parts))
+
+    @property
+    def normalized_args(self) -> FrozenSet[str]:
+        """
+        parts of the message starting at index 1,
+        but they are are stripped of any leading or trailing whitespace
+        and converted to lowercase
+        """
+        return frozenset(map(self._normalize, islice(self.parts, 1, None)))
+
+    @property
+    def args(self) -> List[str]:
+        """
+        parts of the message starting at index 1
+        """
+        return self.parts[1:]
+
     def _parse(self):
         # this weird looking bit is to make sure we do not do unnecessary checks when we have found a match
         # it takes advantage of the fact that python's `or` works as true check/default value provider
@@ -103,6 +132,12 @@ class Message:
             self.tags = Tags(m['tags'])
             self.mentions = get_message_mentions(self)
 
+            # checking if the message contains any bit donations
+            if self.tags and self.tags.bits:
+                self.type = MessageType.BITS
+                # bits and rewards cannot be combined, so return here
+                return True
+
             # checking if its a channel point redemption
             self.reward = self.tags.all_tags.get('msg-id') or self.tags.all_tags.get('custom-reward-id')
             if self.reward is not None:
@@ -234,6 +269,9 @@ class Message:
         elif self.type is MessageType.CHANNEL_POINTS_REDEMPTION:
             return f'{self.author} redeemed reward {self.reward} in #{self.channel_name}'
 
+        elif self.type is MessageType.BITS:
+            return f'{self.author} donated {self.tags.bits} bits to #{self.channel_name}'
+
         return self.raw_msg
 
     def __getitem__(self, item):
